/*
 * @(#)$Id: Ship.java 5321 2012-04-11 17:43:12Z richard $
 * Copyright (c) 2011 Richard J. Povinelli
 */

/**
 * Models the physics of a ship.
 *
 * @version $LastChangedRevision: 5321 $, $LastChangedDate: 2012-04-11 12:43:12 -0500 (Wed, 11 Apr 2012) $
 * @author $LastChangedBy: richard $
 */
public class Ship {

  /** Width of the ships world */
  private static final int COLUMNS = 30;

  /** Depth of the ships world */
  private static final int ROWS = 15;

  /** x component of the velocity vector. */
  private double dx;

  /** y component of the velocity vector. */
  private double dy;

  /** x position */
  private double x;

  /** y position */
  private double y;

  /**
   * Constructs a new ship at the specified coordinates.
   *
   * @param x The x coordinate of the new ship.
   * @param y The y coordinate of the new ship.
   */
  public Ship(double x, double y) {
    this.x  = x;
    this.y  = y;
    this.dx = 0;
    this.dy = 0;
  } // Ship

  /**
   * Gets the x position of the ship.
   * @return x position of the ship.
   */
  public double getX() {
    return x;
  } // getX

  /**
   * Gets the y position of the ship.
   * @return y position of the ship.
   */
  public double getY() {
    return y;
  } // getY

  /**
   * Sets the ship in the negative x direction.
   */
  public void setDxNegative() {
    this.dx = -1;
  }

  /**
   * Sets the ship in the positive x direction.
   *
   */
  public void setDxPositive() {
    this.dx = 1;
  }

  /**
   * Stops the ship from moving in the x direction.
   *
   */
  public void setDxZero() {
    this.dx = 0;
  }

  /**
   * Sets the ship in the negative y direction.
   *
   */
  public void setDyNegative() {
    this.dy = -1;
  }

  /**
   * Sets the ship in the positive y direction.
   *
   */
  public void setDyPositive() {
    this.dy = 1;
  }

  /**
   * Stops the ship moving in the y direction.
   *
   */
  public void setDyZero() {
    this.dy = 0;
  }

  /**
   * Change of time for the ship. Do what a ship does for one tick. Makes sure the ship doesn't fall of the edge
   * of the world.
   */
  public void tick() {
    x += dx;

    if (x < 0) {
      x = 0;
    }

    if (x >= COLUMNS) {
      x = COLUMNS - 1;
    }

    y += dy;

    if (y < 0) {
      y = 0;
    }

    if (y >= ROWS) {
      y = ROWS - 1;
    }
  } // tick
}
